# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class AnalyticsQueryAggregation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AnalyticsQueryAggregation - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'type': 'str',
            'dimension': 'str',
            'metric': 'str',
            'size': 'int',
            'ranges': 'list[AggregationRange]'
        }

        self.attribute_map = {
            'type': 'type',
            'dimension': 'dimension',
            'metric': 'metric',
            'size': 'size',
            'ranges': 'ranges'
        }

        self._type = None
        self._dimension = None
        self._metric = None
        self._size = None
        self._ranges = None

    @property
    def type(self):
        """
        Gets the type of this AnalyticsQueryAggregation.
        Optional type, can usually be inferred

        :return: The type of this AnalyticsQueryAggregation.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this AnalyticsQueryAggregation.
        Optional type, can usually be inferred

        :param type: The type of this AnalyticsQueryAggregation.
        :type: str
        """
        allowed_values = ["termFrequency", "numericRange"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type`, must be one of {0}"
                .format(allowed_values)
            )

        self._type = type

    @property
    def dimension(self):
        """
        Gets the dimension of this AnalyticsQueryAggregation.
        For use with termFrequency aggregations

        :return: The dimension of this AnalyticsQueryAggregation.
        :rtype: str
        """
        return self._dimension

    @dimension.setter
    def dimension(self, dimension):
        """
        Sets the dimension of this AnalyticsQueryAggregation.
        For use with termFrequency aggregations

        :param dimension: The dimension of this AnalyticsQueryAggregation.
        :type: str
        """
        
        self._dimension = dimension

    @property
    def metric(self):
        """
        Gets the metric of this AnalyticsQueryAggregation.
        For use with numericRange aggregations

        :return: The metric of this AnalyticsQueryAggregation.
        :rtype: str
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        """
        Sets the metric of this AnalyticsQueryAggregation.
        For use with numericRange aggregations

        :param metric: The metric of this AnalyticsQueryAggregation.
        :type: str
        """
        
        self._metric = metric

    @property
    def size(self):
        """
        Gets the size of this AnalyticsQueryAggregation.
        For use with termFrequency aggregations

        :return: The size of this AnalyticsQueryAggregation.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """
        Sets the size of this AnalyticsQueryAggregation.
        For use with termFrequency aggregations

        :param size: The size of this AnalyticsQueryAggregation.
        :type: int
        """
        
        self._size = size

    @property
    def ranges(self):
        """
        Gets the ranges of this AnalyticsQueryAggregation.
        For use with numericRange aggregations

        :return: The ranges of this AnalyticsQueryAggregation.
        :rtype: list[AggregationRange]
        """
        return self._ranges

    @ranges.setter
    def ranges(self, ranges):
        """
        Sets the ranges of this AnalyticsQueryAggregation.
        For use with numericRange aggregations

        :param ranges: The ranges of this AnalyticsQueryAggregation.
        :type: list[AggregationRange]
        """
        
        self._ranges = ranges

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

