# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class DomainOrgRoleDifference(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DomainOrgRoleDifference - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'removed_permission_policies': 'list[DomainPermissionPolicy]',
            'added_permission_policies': 'list[DomainPermissionPolicy]',
            'same_permission_policies': 'list[DomainPermissionPolicy]',
            'user_org_role': 'DomainOrganizationRole',
            'role_from_default': 'DomainOrganizationRole'
        }

        self.attribute_map = {
            'removed_permission_policies': 'removedPermissionPolicies',
            'added_permission_policies': 'addedPermissionPolicies',
            'same_permission_policies': 'samePermissionPolicies',
            'user_org_role': 'userOrgRole',
            'role_from_default': 'roleFromDefault'
        }

        self._removed_permission_policies = None
        self._added_permission_policies = None
        self._same_permission_policies = None
        self._user_org_role = None
        self._role_from_default = None

    @property
    def removed_permission_policies(self):
        """
        Gets the removed_permission_policies of this DomainOrgRoleDifference.


        :return: The removed_permission_policies of this DomainOrgRoleDifference.
        :rtype: list[DomainPermissionPolicy]
        """
        return self._removed_permission_policies

    @removed_permission_policies.setter
    def removed_permission_policies(self, removed_permission_policies):
        """
        Sets the removed_permission_policies of this DomainOrgRoleDifference.


        :param removed_permission_policies: The removed_permission_policies of this DomainOrgRoleDifference.
        :type: list[DomainPermissionPolicy]
        """
        
        self._removed_permission_policies = removed_permission_policies

    @property
    def added_permission_policies(self):
        """
        Gets the added_permission_policies of this DomainOrgRoleDifference.


        :return: The added_permission_policies of this DomainOrgRoleDifference.
        :rtype: list[DomainPermissionPolicy]
        """
        return self._added_permission_policies

    @added_permission_policies.setter
    def added_permission_policies(self, added_permission_policies):
        """
        Sets the added_permission_policies of this DomainOrgRoleDifference.


        :param added_permission_policies: The added_permission_policies of this DomainOrgRoleDifference.
        :type: list[DomainPermissionPolicy]
        """
        
        self._added_permission_policies = added_permission_policies

    @property
    def same_permission_policies(self):
        """
        Gets the same_permission_policies of this DomainOrgRoleDifference.


        :return: The same_permission_policies of this DomainOrgRoleDifference.
        :rtype: list[DomainPermissionPolicy]
        """
        return self._same_permission_policies

    @same_permission_policies.setter
    def same_permission_policies(self, same_permission_policies):
        """
        Sets the same_permission_policies of this DomainOrgRoleDifference.


        :param same_permission_policies: The same_permission_policies of this DomainOrgRoleDifference.
        :type: list[DomainPermissionPolicy]
        """
        
        self._same_permission_policies = same_permission_policies

    @property
    def user_org_role(self):
        """
        Gets the user_org_role of this DomainOrgRoleDifference.


        :return: The user_org_role of this DomainOrgRoleDifference.
        :rtype: DomainOrganizationRole
        """
        return self._user_org_role

    @user_org_role.setter
    def user_org_role(self, user_org_role):
        """
        Sets the user_org_role of this DomainOrgRoleDifference.


        :param user_org_role: The user_org_role of this DomainOrgRoleDifference.
        :type: DomainOrganizationRole
        """
        
        self._user_org_role = user_org_role

    @property
    def role_from_default(self):
        """
        Gets the role_from_default of this DomainOrgRoleDifference.


        :return: The role_from_default of this DomainOrgRoleDifference.
        :rtype: DomainOrganizationRole
        """
        return self._role_from_default

    @role_from_default.setter
    def role_from_default(self, role_from_default):
        """
        Sets the role_from_default of this DomainOrgRoleDifference.


        :param role_from_default: The role_from_default of this DomainOrgRoleDifference.
        :type: DomainOrganizationRole
        """
        
        self._role_from_default = role_from_default

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

