from __future__ import absolute_import

# import apis into api package
from .alerting_api import AlertingApi
from .analytics_api import AnalyticsApi
from .attributes_api import AttributesApi
from .authorization_api import AuthorizationApi
from .configuration_api import ConfigurationApi
from .content_management_api import ContentManagementApi
from .conversations_api import ConversationsApi
from .fax_api import FaxApi
from .geolocation_api import GeolocationApi
from .greetings_api import GreetingsApi
from .groups_api import GroupsApi
from .identity_provider_api import IdentityProviderApi
from .languages_api import LanguagesApi
from .locations_api import LocationsApi
from .notifications_api import NotificationsApi
from .o_auth_api import OAuthApi
from .organization_api import OrganizationApi
from .outbound_api import OutboundApi
from .presence_api import PresenceApi
from .quality_api import QualityApi
from .recording_api import RecordingApi
from .response_management_api import ResponseManagementApi
from .routing_api import RoutingApi
from .search_api import SearchApi
from .stations_api import StationsApi
from .suggest_api import SuggestApi
from .telephony_providers_edge_api import TelephonyProvidersEdgeApi
from .tokens_api import TokensApi
from .user_recordings_api import UserRecordingsApi
from .users_api import UsersApi
from .utilities_api import UtilitiesApi
from .voicemail_api import VoicemailApi
